@@ -4,31 +4,20 @@
 use strict;
 use warnings;
 
-BEGIN {
-    # Clear out any proxy settings
-    delete $ENV{$_} for qw(http_proxy HTTP_PROXY);
-}
-
-use DateTime;
-use Elasticsearch::Compat;
-use JSON;
-use LWP::Simple;
-use Getopt::Long;
+use Getopt::Long qw(:config no_ignore_case no_ignore_case_always);
 use Pod::Usage;
+use CLI::Helpers qw(:all);
 use App::ElasticSearch::Utilities qw(:all);
 
 #------------------------------------------------------------------------#
 # Argument Collection
 my %opt;
 GetOptions(\%opt,
-    'local',
     'all',
-    'host:s',
-    'port:i',
     'dry-run',
     'delete',
     'delete-days:i',
-    'replicas:i',
+    'replicas',
     'replicas-min:i',
     'replicas-age:s',
     'optimize',
@@ -46,20 +35,13 @@ GetOptions(\%opt,
 pod2usage(-exitval => 0) if $opt{help};
 pod2usage(-exitval => 0, -verbose => 2) if $opt{manual};
 
-#------------------------------------------------------------------------#
-# Host or Local
-pod2usage(-exitval => 1, -message => "Destination host not specified, use --local or --host.") unless defined $opt{local} or defined $opt{host};
-
 my %CFG = (
     'optimize-days'  => 1,
     'delete-days'    => 90,
     'replicas-min'   => 0,
     'dry-run'        => 0,
     'replicas-age'   => "1,30",
-    'index-basename' => 'logstash',
-    'date-separator' => '.',
     timezone         => 'Europe/Amsterdam',
-    port             => 9200,
     delete           => 0,
     optimize         => 0,
     replicas         => 0,
@@ -90,121 +72,75 @@ else {
 $CFG{'replicas-min'} = 0 if $CFG{'replicas-min'} < 0;
 
 # Create the target uri for the ES Cluster
-my $TARGET = exists $opt{host} && defined $opt{host} ? $opt{host} : 'localhost';
-$TARGET .= ":$CFG{port}";
-debug("Target is: $TARGET");
-debug_var(\%CFG);
+my $es = es_connect();
 
-my $es = Elasticsearch::Compat->new(
-    servers   => [ $TARGET ],
-    transport => 'http',
-    timeout   => 0,     # Do Not Timeout
-);
-
-# Delete Indexes older than a certain point
-my $NOW      = DateTime->now(time_zone => $CFG{timezone})->truncate( to => 'day' );
-my $DEL      = $NOW->clone->subtract( days => $CFG{'delete-days'} );
-my $OPTIMIZE = $NOW->clone->subtract( days => $CFG{'optimize-days'} );
-my @AGES     = grep { my $x = int($_); $x > 0; } split /,/, $CFG{'replicas-age'};
+# Ages for replica management
+my @AGES = grep { my $x = int($_); $x > 0; } split /,/, $CFG{'replicas-age'};
 
 # Retrieve a list of indexes
-my $d_res = $es->cluster_state(
-    filter_nodes         => 1,
-    filter_routing_table => 1,
+my @indices = es_indices(
+    check_state => 0,
+    check_dates => 0,
 );
-my $indices = $d_res->{metadata}{indices};
-if ( !defined $indices ) {
-    output({color=>"red"}, "Unable to locate indices in status!");
-    exit 1;
-}
 
 # Loop through the indices and take appropriate actions;
-foreach my $index (sort keys %{ $indices }) {
-    verbose("$index being evaluated");
-    debug_var($indices->{$index});
+foreach my $index (sort @indices) {
+    verbose({level=>2},"$index being evaluated");
 
-    my @words = split /\-/, $index;
-    my $dateStr = pop @words;
-
-    next unless defined $dateStr && $dateStr =~ /\d{4}.?\d{2}.?\d{2}/;
-
-    my $basename = join('-', @words);
-    debug("Basename: $basename");
-    debug("Date string: $dateStr");
-    my %words = map { $_=>1 } @words;
-    next unless exists $words{$CFG{'index-basename'}};
-
-    my $sep = $CFG{'date-separator'};
-    my @parts = split /\Q$sep\E/, $dateStr;
-    my $idx_dt = DateTime->new( year => $parts[0], month => $parts[1], day => $parts[2] );
+    my $days_old = es_index_days_old( $index );
 
     # Delete the Index if it's too old
-    if( $CFG{delete} && $idx_dt < $DEL ) {
+    if( $CFG{delete} && $CFG{'delete-days'} < $days_old ) {
         output({color=>"red"}, "$index will be deleted.");
-        eval {
-            my $rc = $es->delete_index( index => $index );
-        } unless $CFG{'dry-run'};
+        my $rc = es_delete_index($index);
         next;
     }
 
     # Manage replicas
     if( $CFG{replicas} ) {
-        my $days_old  = $NOW->delta_days($idx_dt)->delta_days;
-        my $current_replicas = $indices->{$index}{settings}{"index.number_of_replicas"};
-        debug({color=>"cyan"}, " - index is $days_old days old");
-        my $replicas = $CFG{replicas};
+        my %shards = es_index_shards($index);
+        debug({color=>"cyan"}, "$index: index is $days_old days old");
+        # Default for replicas is primaries - 1;
+        my $replicas = $shards{primaries} - 1;
         foreach my $age ( @AGES ) {
             if ( $days_old >= $age ) {
                 $replicas--;
             }
         }
         $replicas = $CFG{'replicas-min'} if $replicas < $CFG{'replicas-min'};
-        if ( $replicas != $current_replicas ) {
-            verbose({color=>'yellow'}, " - should have $replicas replicas, has $current_replicas");
-            eval {
-                $es->update_index_settings(
-                    index => $index,
-                    settings => { number_of_replicas => $replicas},
-                );
-            } unless $CFG{'dry-run'};
-            if (my $err = $@ ) {
-                output({color=>'red'}, "Failed setting replicas to $replicas for $index.", $err);
+        if ( $shards{primaries} > 0 && $shards{replicas} != $replicas ) {
+            verbose({color=>'yellow'}, "$index: should have $replicas replicas, has $shards{replicas}");
+            my $result = es_request('_settings',
+                { index => $index, method => 'PUT' },
+                { index => { number_of_replicas => $replicas} },
+            );
+            if(!defined $result) {
+                output({color=>'red',indent=>1}, "Error encountered.");
+            }
+            else {
+                output({color=>"green"}, "$index: Successfully set replicas to $replicas");
             }
         }
     }
 
     # Run optimize?
     if( $CFG{optimize} ) {
-        my $segment_ratio = undef;
-        eval {
-            my $json = get( qq{http://$TARGET/$index/_segments} );
-            my $res = decode_json( $json );
-            my $shard_data = $res->{indices}{$index}{shards};
-            my $shards = 0;
-            my $segments = 0;
-            foreach my $id (keys %{$shard_data} ){
-                $segments += $shard_data->{$id}[0]{num_search_segments};
-                $shards++;
-            }
-            if( $shards > 0 ) {
-                $segment_ratio = sprintf( "%0.2f", $segments / $shards );
-            }
-        };
+        my $segdata = es_segment_stats( $index );
 
-        if( $idx_dt <= $OPTIMIZE && defined($segment_ratio) && $segment_ratio > 1 ) {
-            my $error = undef;
+        my $segment_ratio = undef;
+        if( defined $segdata && $segdata->{shards} > 0 ) {
+            $segment_ratio = sprintf( "%0.2f", $segdata->{segments} / $segdata->{shards} );
+        }
+
+        if( $days_old >= $CFG{'optimize-days'} && defined($segment_ratio) && $segment_ratio > 1 ) {
             verbose({color=>"yellow"}, "$index: required (segment_ratio: $segment_ratio).");
 
-            eval {
-                my $o_res = $es->optimize_index(
-                    index            => $index,
-                    max_num_segments => 1,
-                    wait_for_merge   => 0,
-                );
+            my $o_res = es_optimize_index($index);
+            if( !defined $o_res ) {
+                output({color=>"red"}, "$index: Encountered error during optimize");
+            }
+            else {
                 output({color=>"green"}, "$index: $o_res->{_shards}{successful} of $o_res->{_shards}{total} shards optimized.");
-            } unless $CFG{'dry-run'};
-            if( my $error = $@ ) {
-                output({color=>"red"}, "$index: Encountered error during optimize: $error");
             }
         }
         else {
@@ -228,7 +164,7 @@ es-daily-index-maintenance.pl - Run to prune old indexes and optimize existing
 
 =head1 VERSION
 
-version 1.5
+version 1.6
 
 =head1 SYNOPSIS
 
@@ -238,10 +174,6 @@ Options:
 
     --help              print help
     --manual            print full manual
-    --dry-run           Tell me what you would do, but don't do it.
-    --local             Poll localhost and use name reported by ES
-    --host|-H           Host to poll for statistics
-    --local             Assume localhost as the host
     --all               Run delete and optimize
     --delete            Run delete indexes older than
     --delete-days       Age of oldest index to keep (default: 90)
@@ -250,10 +182,13 @@ Options:
     --replicas          Sets the number of initial replicas, and manages replica aging
     --replicas-age      CSV list of ages in days to decrement number of replicas
     --replicas-min      Minimum number of replicas this index may have, default:0
-    --index-basename    Default is 'logstash'
-    --date-separator    Default is '.'
-    --quiet             Ideal for running on cron, only outputs errors
-    --verbose           Send additional messages to STDERR
+
+From CLI::Helpers:
+
+    --color             Boolean, enable/disable color, default use git settings
+    --verbose           Incremental, increase verbosity
+    --debug             Show developer output
+    --quiet             Show no output (for cron)
 
 =head1 DESCRIPTION
 
@@ -305,26 +240,6 @@ The minimum number of replicas to allow replica aging to set.  The default is 0
 
     --replicas-min=1
 
-=item B<local>
-
-Optional, operate on localhost (if not specified, --host required)
-
-=item B<host>
-
-Optional, the host to maintain (if not specified --local required)
-
-=item B<verbose>
-
-Verbose stats, to not interfere with cacti, output goes to STDERR
-
-=item B<help>
-
-Print this message and exit
-
-=item B<manual>
-
-Print this message and exit
-
 =back
 
 =head1 AUTHOR
